@@ -746,8 +746,8 @@ extern int glXSendPbufferToVideoNV(Display *dpy, GLXPbuffer pbuf,
 
 extern int glXGetVideoInfoNV(Display *dpy, int screen,
                              GLXVideoDeviceNV VideoDevice,
-                             unsigned long *pulCounterOutputVideo,
-                             unsigned long *pulCounterOutputPbuffer);
+                             unsigned long *pulCounterOutputPbuffer,
+                             unsigned long *pulCounterOutputVideo);
 #endif
 typedef int ( * PFNGLXGETVIDEODEVICENVPROC) (Display *dpy,
                                              int screen,
@@ -774,8 +774,8 @@ typedef int ( * PFNGLXSENDPBUFFERTOVIDEONVPROC) (Display *dpy,
 
 typedef int ( * PFNGLXGETVIDEOINFONVPROC) (Display *dpy, int screen,
                                            GLXVideoDeviceNV VideoDevice,
-                                           unsigned long *pulCounterOutputVideo,
-                                           unsigned long *pulCounterOutputPbuffer);
+                                           unsigned long *pulCounterOutputPbuffer,
+                                           unsigned long *pulCounterOutputVideo);
 #endif
 
 #ifndef GLX_EXT_texture_from_pixmap
